/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {
	fetch,
	openConfirmModal,
	openSimpleInputModal,
	openToast,
} from 'frontend-js-web';

function deleteEntry(deleteURL) {
	openConfirmModal({
		message: Liferay.Language.get('are-you-sure-you-want-to-delete-this'),
		onConfirm: (isConfirmed) => {
			if (isConfirmed) {
				fetch(deleteURL, {
					method: 'DELETE',
				}).then((response) => {
					if (response.ok) {
						window.location.reload();
					}
					else {
						openToast({
							message: Liferay.Language.get(
								'an-unexpected-error-occurred'
							),
							type: 'danger',
						});
					}
				});
			}
		},
	});
}

function renameEntry(renameURL, value) {
	openSimpleInputModal({
		dialogTitle: Liferay.Language.get('rename'),
		formSubmitURL: renameURL,
		mainFieldLabel: Liferay.Language.get('name'),
		mainFieldName: 'name',
		mainFieldValue: value,
		namespace: '',
		onFormSuccess: (response) => {
			if (response.success) {
				window.location.reload();
			}
			else {
				openToast({
					message: Liferay.Language.get(
						'an-unexpected-error-occurred'
					),
					type: 'danger',
				});
			}
		},
	});
}

export {deleteEntry, renameEntry};
